Modules
Macros
Structs
- Install
Result - Install result containing optional checksum used for verification
- Metadata
- Package
Action Context - Package
Action Response - Package
Installed Context - Package
Installed Response - Package
Request - Plugin
- System
Dependency - A single
PLUGIN.systemDependenciesentry — a system prerequisite the plugin needs before it can install (build tools, libraries, …). Exactly one ofbin/pkgconfig/sharedlib/commandmust be set;packagesmaps a package-manager name (brew, apt, dnf, pacman, apk) to the package that provides the capability, used only as a remediation hint. - Vfox
Enums
- Verified
Attestation - The type of attestation that was successfully verified.
- Vfox
Error
Functions
- cancel_
http_ requests - Cancel in-flight HTTP operations started by vfox plugins.