Plugin

Struct Plugin 

pub struct Plugin {
    pub name: String,
    pub dir: PathBuf,
    /* private fields */
}

Fields

name: Stringdir: PathBuf

Implementations

Source

impl Plugin

pub fn available(&self) -> Result<Vec<AvailableVersion>>

pub async fn available_async(&self) -> Result<Vec<AvailableVersion>>

Source

impl Plugin

pub async fn backend_exec_env( &self, ctx: BackendExecEnvContext, ) -> Result<BackendExecEnvResponse>

Source

impl Plugin

pub async fn backend_install( &self, ctx: BackendInstallContext, ) -> Result<BackendInstallResponse>

Source

impl Plugin

pub async fn backend_list_versions( &self, ctx: BackendListVersionsContext, ) -> Result<BackendListVersionsResponse>

Source

impl Plugin

pub async fn env_keys<T: Serialize>( &self, ctx: EnvKeysContext<T>, ) -> Result<Vec<EnvKey>>

Source

impl Plugin

pub async fn mise_env<T: Serialize>( &self, ctx: MiseEnvContext<T>, ) -> Result<MiseEnvResult>

Source

impl Plugin

pub async fn mise_path<T: Serialize>( &self, ctx: MisePathContext<T>, ) -> Result<Vec<String>>

Source

impl Plugin

pub async fn parse_legacy_file( &self, legacy_file: &Path, ) -> Result<ParseLegacyFileResponse>

Source

impl Plugin

pub async fn post_install(&self, ctx: PostInstallContext) -> Result<()>

Source

impl Plugin

pub async fn pre_install(&self, version: &str) -> Result<PreInstall>

pub async fn pre_install_for_platform( &self, version: &str, os: &str, arch: &str, ) -> Result<PreInstall>

Source

impl Plugin

pub async fn pre_use( &self, _vfox: &Vfox, _legacy_file: &Path, ) -> Result<PreUseResponse>

Source

impl Plugin

pub fn from_dir(dir: &Path) -> Result<Self>

pub fn from_embedded( name: &str, embedded: &'static EmbeddedPlugin, ) -> Result<Self>

pub fn from_name(name: &str) -> Result<Self>

pub fn from_name_or_dir(name: &str, dir: &Path) -> Result<Self>

pub fn is_embedded(&self) -> bool

pub fn set_cmd_env(&self, env: &IndexMap<String, String>) -> Result<()>

Store an environment map in the Lua registry for use by cmd.exec(). This allows env module hooks to run commands that find mise-managed tools on PATH.

pub fn list() -> Result<Vec<String>>

pub fn get_metadata(&self) -> Result<Metadata>

pub fn sdk_info(&self, version: String, install_dir: PathBuf) -> Result<SdkInfo>